Thank you for contributing shortmagnet
========================================================

## If you are creating an issue:

Make sure to report wich specific commit did the issue ocurr on.
Make sure to run the software on a clean environment.

## If you're creating pull request:

Please, run tox before.
